require 'nokogiri'
require 'mechanize'

class NotLoggedInError < StandardError; end

class FacebookWordCounter
	FACEBOOK_URL_PREFIX = "https://www.facebook.com/"
	FACEBOOK_URL_SUFFIX = "?_fb_noscript=1"

	def self.setup_browser_agent(username, password)
		@agent = Mechanize.new
		@agent.get(FACEBOOK_URL_PREFIX)
		login(username, password)
	end

	def self.get_word_counts(*facebook_pages)
		raise NotLoggedInError unless logged_in?

		facebook_pages.map do |url|
			no_js_url = "#{FACEBOOK_URL_PREFIX}#{url}#{FACEBOOK_URL_SUFFIX}"
			@agent.get(no_js_url)
			{
				name: get_facebook_name,
				image: get_facebook_photo_url,
				words: get_word_counts_on_page
			}
		end
	end

	private

	def self.login(username, password)
		form = @agent.page.forms.first
		form.email = username
		form.pass = password
		form.submit
	end

	def self.logged_in?
		!(@agent.page.uri.to_s =~ /login_attempt/)
	end

	def self.get_facebook_name
		@agent.page.title
	end

	def self.get_word_counts_on_page
		all_words = @agent.page.search(".userContent").map { |post| TextCleaner.clean_text(post.text) }.join(' ')
		WordCounter.count_words(all_words)
	end

	def self.get_facebook_photo_url
		@agent.page.search("img.profilePic").first['src']
	end
end
